@@ -7,7 +7,7 @@ function (formula, locations, data, model, debug.level = 1, set)
         stop("formula should be of class formula")
     if (missing(model)) 
         stop("no model to fit")
-    if (class(model) != "variogram.model") 
+    if (!inherits(model, "variogram.model"))
         stop("model should be of class variogram.model (use vgm)")
     fit.sills = rep(TRUE, length(model$model))
     fit.ranges = rep(FALSE, length(model$model))
