@@ -4,5 +4,9 @@ double sample_var(double *list, double mean, int n);
 double sample_std(double *list, double mean, int n);
 double est_quant(double *list, double p, int n);
 void calc_r(double *a, double *b, int n, double *r);
-int d_cmp(const double *a, const double *b);
+int 
+#ifdef SPLUS6WIN32
+	__cdecl
+#endif
+	d_cmp(const double *a, const double *b);
 int stats(char *name, int silent, double q);
